/* 
xdipo

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "xdipo.h"

FD_xdipo *fdui;

FILE *filefd;


int save_setting(char *type, char *string)
{
char pathfilename[TEMP_SIZE];
FILE *setting_file;

/* combine with home directory */
sprintf(pathfilename, "%s/.xdipo/setup/%s", home_dir, type);
setting_file = fopen(pathfilename, "w");
if(! setting_file)
	{
	fl_show_alert("Cannot open file for write:", pathfilename, "", 0);
	if(debug_flag)
		{
		fprintf(stderr, "\nCannot open setting file %s for write\n",\
		pathfilename);
		}
	return 0;
	}

fprintf(setting_file, "%s", string);
fclose(setting_file);
return 1;	
}/* end function save_setting */


char *load_setting(char *type)
{
int a;
char temp[1024];
char pathfilename[TEMP_SIZE];
FILE *setting_file;

/* combine with home directory */
sprintf(pathfilename, "%s/.xdipo/setup/%s", home_dir, type);
setting_file = fopen(pathfilename, "r");
if(! setting_file)
	{
	fl_show_alert("Cannot open file for read:", pathfilename, "", 0);
	if(debug_flag)
		{
		fprintf(stderr, "\nCannot open setting file %s for read\n",\
		pathfilename);
		}
	return 0;
	}

a = readline(setting_file, temp);/* closes file if EOF */	
if(a != EOF) fclose(setting_file);
return strsave(temp);
}/* end function load_setting */


int save_fontsizes()
{
char temp[TEMP_SIZE];
sprintf(temp,\
"%d %d",\
main_form_fontsize,\
timer_form_fontsize\
);

if(! save_setting("fontsizes", temp) ) return 0;

return 1;
}/* end function save_fontsizes */


int load_fontsizes()
{
char *data_read;
 
data_read = (char *) load_setting("fontsizes");
if(! data_read) return 0;
sscanf(data_read,\
"%d %d",\
&main_form_fontsize,\
&timer_form_fontsize\
);

free(data_read);

/* for main form */
//fl_set_browser_fontsize(fdui -> main_form_stream_browser, integer_to_fontsize(main_form_fontsize) );

/* for timer form */
fl_set_browser_fontsize(fdui -> timer_form_browser, integer_to_fontsize(timer_form_fontsize) );

return 1;
}/* end function load_fontsizes */


#ifdef SAVE_SETTINGS
int save_general_settings()
{
char *ptr;
char temp[TEMP_SIZE];

sprintf(temp,\
"%d %d %d %d %d %d %d %d %d %d %d %d %d %d",\
selected_program,\
sort_mode,\
selected_volume,\
log_ca_flag,\
show_ca_flag,\
teletext_flag,\
adjacent_flag,\
service_type_filter,\
selected_driver,\
card_share_mode,\
selected_decoder,\
log_signal_quality_flag,\
inhibit_recorder_flag,\
program_mode\
);

save_setting("global_flags", temp);

return 1;
}/* end function save_general_settings */


int load_general_settings()
{
char temp[512];
double da;
int error;
char *ptr;
FILE *pptr;

if(debug_flag)
	{
	fprintf(stderr, "load_general_settings(): arg none\n");
	}

card_share_mode = CARD_SHARE_OFF;
error = 0;
ptr = load_setting("global_flags");
if(ptr)
	{
	sscanf(ptr,\
	"%d %d %d %d %d %d %d %d %d %d %d %d %d %d",\
	&selected_program,\
	&sort_mode,\
	&selected_volume,\
	&log_ca_flag,\
	&show_ca_flag,\
	&teletext_flag,\
	&adjacent_flag,\
	&service_type_filter,\
	&selected_driver,\
	&card_share_mode,\
	&selected_decoder,\
	&log_signal_quality_flag,\
	&inhibit_recorder_flag,\
	&program_mode\
	);

	free(ptr);

	load_programs();

	/* build the list so we have a valid browser_line, not stored */
	/* note thus will be done again in main */
	if(! show_programs(SHOW_SELECTED_IN_MIDDLE) )
		{
		return;
		}

	/* select program */
	if(! select_program(selected_program) )
		{
//		return;
		}

	/* do the volume thing */
	da = selected_volume / 100.0;
	fl_set_slider_value(fdui -> main_form_volume_slider, da);

	sprintf(temp, "cmix %s %d\n", MIXER_VOLUME, selected_volume);
	pptr = popen(temp, "r");
	pclose(pptr);

	/* set the inhibit recorder button */
	fl_set_button(fdui -> main_form_inhibit_timers_button,\
	inhibit_recorder_flag);

	/* set the sort button */
	set_sort_button();

	/* set the log ca button */
	fl_set_button(fdui -> main_form_log_ca_button, log_ca_flag);

	/* set the show ca button */
	fl_set_button(fdui -> main_form_show_ca_button, show_ca_flag);

	/*
	show the log if requested, this is done in xdipo_main.c AFTER
	the main form is drawn
	*/

	/* set the teletext button */
	fl_set_button(fdui -> main_form_teletext_button, teletext_flag);

	/* set the service_type filter button */
	set_service_button(service_type_filter);

	/* set file mnu tick boxes */
	set_main_form_file_menu_adjacent();
	set_main_form_file_menu_decoder();
	set_driver_select_button(selected_driver);
	set_main_form_recorder_menu_logging();

	/* start the teletext decoder if needed */
	if(teletext_flag)
		{
//		start_teletext_decoder();
		start_teletext_viewer();
		}

	if(program_mode != PROGRAM_MODE_USE_XCHA)  close_all_devices();

	set_main_form_file_menu_card_share(card_share_mode);

	set_main_form_file_menu_program_mode(program_mode);	
	}
else
	{
	error = 1;
	}
/* 
create setup files from defaults if some not found,
else use values just read.
*/
if(error) save_general_settings();

return 1;
}/* end function load_general_settings */

#endif /* SAVE_SETTINGS */


char *expand_tabs(char *text, int tabsize)
{
int c, i, j, k;
int tabs;
char *space;

if(debug_flag)
	{
	fprintf(stderr, "expand_tabs(): arg text=%s tabsize=%d\n",\
	text, tabsize);
	}

/* argument check */
if(! text) return 0;
if(tabsize < 0) return 0;

/* determine how many tabs, so we can calculate the required space */
i = 0;
tabs = 0;
while(1)
	{
	c = text[i];
	if(c == 0) break;
	if(c == 9) tabs++;
	i++;
	}/* end while all characters in text */

space = malloc(strlen(text) + (tabs * tabsize) - tabs + 1 + 1);
if(! space) return 0;

/* copy and expand */
i = 0;
j = 0;
while(1)
	{
	c = text[i];
	if(c == 9)
		{
		for(k = 0; k < tabsize; k++)
			{
			space[j] = ' ';
			j++;
			}
		i++;
		continue;
		}
	else
		{
		space[j] = c;
		}
	if(c == 0) break;
	i++;
	j++;
	}
return space;
}/* end function expand_tabs */


